@@ -1,6 +1,9 @@
 package Beekeeper;
 
-our $VERSION = '0.01_01';
+use strict;
+use warnings;
+
+our $VERSION = '0.02_01';
 
 1;
 
@@ -152,9 +155,9 @@ another workers.
 
 A worker class just declares on startup which methods it will accept, then implements them:
 
-package MyApp::Worker;
+  package MyApp::Worker;
   
-use base 'Beekeeper::Worker';
+  use base 'Beekeeper::Worker';
   
   sub on_startup {
       my $self = shift;
@@ -256,9 +259,30 @@ The framework includes these command line tools to manage worker pools:
 - C<bkpr-restart> gracefully restarts local or remote worker pools.
 
 
-=head1 WARNING
- 
-This is beta quality software.
+=head3 Examples
+
+This distribution includes some examples that can be run out of the box using an internal
+`ToyBroker` (so no install of a proper broker is needed):
+
+C<examples/basic> is a barebones example of the usage of Beekeper.
+
+C<examples/flood> allows to estimate the performance of a Beekeper setup.
+
+C<examples/webstomp> use a service from a browser using WebSockets.
+
+C<examples/chat> implements a real world setup with isolated buses and redundancy.
+
+
+=head3 TODO
+
+Since this project was started (and even then) STOMP has been completely surpassed 
+as a fast and simple messaging protocol by MQTT. And since 2019, when MQTT
+version 5.0 was released, many brokers started to implement the routing features
+needed by Beekeeper to run.
+
+So the underlying broker protocol should be changed to MQTT, in order to take advantage
+of better supported modern brokers.
+
 
 =head1 SEE ALSO
  
