@@ -1,5 +1,8 @@
 package Beekeeper::JSONRPC;
 
+use strict;
+use warnings;
+
 our $VERSION = '0.01';
 
 =head1 NAME
@@ -45,6 +48,8 @@ sub error {
 
 1;
 
+=encoding utf8
+
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
